.. all-saltext.vault.wrapper:

_______________
Wrapper Modules
_______________

.. currentmodule:: saltext.vault.wrapper

.. autosummary::
    :toctree:

    vault
    vault_db
    vault_pki
    vault_ssh
